%% Create session and file for inputs

clear all			% clear in case you have some undesirable leftover in the workspace

global sys session last_rec rec

sessionfile = load_session();         	% load parameters of the previous recording session

% USER INPUT REQ'D: 			

session.project = 'MOST';	% brief name of the project 

session.trial_ID = 1;		% numeric trial number included in TrialID

session.lane_name = 'B';	% lane name

session.pattern = 5;		% pattern number. As I understand, it cannot be larger than 5 or 7?

session.observer = 'Chelsey Yesnik';	% observer name for log

    %  source position relative to the coordinate origin (inline, crossline) 

    	%  Other parameters need to be changed only occasionally, 

        %  pattern no. (integer), where there will be predefined layouts tried 				
        %  dq Rate (in Hz, where max resolution is 51,200s), 
        %  measurement Duration (in seconds, typically 10s is sufficient for booting system and measuring),
        %  sensor type, 
        %  hammer type, 
        %  lane number
        %  number of load cycles


session.hammer_position_cm = [ 100, 0 ];	% hammer position [inline, crossline] (cm)

session.hammer_ID = 'H1';
session.hammer_mass = 227;	% hammer mass in grams

session.dq_Rate = 51200;

session.dq_duration_seconds = 10;

session.dq_load_cycles = 1200;

% Set directory (folder name) for your log and pattern files
% Data files will be placed in subdirectory 'accel/' of this directory.
% If any directories do not exist, they will be created by the program.

%session.dir_project = '../test_project/';	% this is what I use for testing

session.dir_project = '../MOST_May18_2022/';	% this is for production work

% name of CSV database log file. If this string is not empty, aline will be appended to it
% during every run of thsi program

session.csv_log_filename = '../MASW_Database_07132022_2.csv';	

% notes

session.Note1 = '';
session.Note2 = '';
session.Note3 = '';
session.Note4 = '';
session.Note5 = '';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%	The following fields are derived from the above
%%	and you likely do not need to change them
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% line number is now composed of lane and pattern numbers

session.line_no = 10*(session.lane_name - 'A' + 1) + session.pattern;

% suffix appended to log file name after line number and location and before '.txt'.
% you can probably keep it auto filled based on the preceding field like shown below,
% but may also change to something else:

session.log_suffix = '';	% before, it was: sprintf('after %d cycles',session.dq_load_cycles);

session.name = sprintf('Trial %d', session.trial_ID);	% more detailed name shown as '% Title' in the log

session.location = sprintf('Lane %s', session.lane_name);	
		% description of location going into log file (spaces replaced with '_') and into the logs 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%	Do not edit code below this point
%% 	Begin operation!
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% set 	session.trial_no = next available trial number after current session.trial_no,
%	session.src_no = next source number in the log,
%	and alsp set the corresponding file names

new_trial();	

%% if DAQ emulation exists (for software testing), use it

testmode = exist('../daq_emulation');

if testmode 
	addpath('../daq_emulation')
end


% read from the log parameters of the last trial

if exist(session.log_filename)
	[ last_rec.line, ~, ~, ~, last_rec.pattern, ~, last_rec.ffid, last_rec.src ] = params_ffid(session.log_filename);
else
	last_rec = [];
end

%% Create Data Acquisition		

sys = config_daq(session.dq_Rate);

beep()					
disp(sprintf('Line %d, Trial %d; Strike -->\n', session.line_no, session.trial_no))

%% Acquire, Plot and Save Data

% Read the data in timetable format; save mat variables from trial; 
% plot the read data on labeled axes; and save acceleration vs. time 
% readings in .txt file format. Read output from acclerometers for 
% specified duration

data = read(sys.dq,seconds(session.dq_duration_seconds));

% write out all parameters into log and csv files

write_log();
write_log_csv();

% transform the 'data' structure into an ordinary matrix 'rec0'

rec0 = data_record(data);

rec = rec0;	% work array that may be changed by first_display()

% Plot readings of acceleration vs. time in 'rec':

ts = first_display();

% Save acceleration vs. time readings in .txt file
% Save only 100 ms before and 500 ms after the largest peak shown in first_display()
% This should be enough for anything you might want to do with these data   - I.M.

ind = find(rec0(:,1) > ts - 100.0 & rec0(:,1) < ts + 500.0);	% range of rows in rec0 to save

fid = fopen(session.data_filename,'w');		% changed to automatic file name and added '%' in header - I.M.

fprintf(fid,"%% Time(ms) Hammer    Accel_1    Accel_2   Accel_3   Accel_4   Accel_5   Accel_6   Accel_7   Accel_8   Accel_9   Accel_10   Accel_11   Accel_12   Accel_13   Accel_14   Accel_15\r\n\n");
fprintf(fid," %-5.2f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f  %-1.6f\r\n",transpose(rec0(ind,:)));
fclose(fid);

save(sessionfile,'session')

%% Clean Up
% Clear all DataAcquisition and channel objects - you don't really need this cleanup. 
% If you do not do this,
% you will be able to check the state of your system or data after this program is finished.   - I.M.

%clear sys.dq

