%% Configures all channels in Chelsey's DAQ for a given sampling rate 'dq_rate'
%% Returns structure 'sys' containing DAQ handle sys.dq and descriptors of all channels

function sys = config_daq( dq_rate )

	%%Create Data Acquisition

	sys.dq = daq('ni');
	sys.dq.Rate = dq_rate;
 
	%Add channels, and set DAQ and channel properties

	sys.ch0 = addinput(sys.dq,'cDAQ1Mod1','ai0','Voltage');
	sys.ch1 = addinput(sys.dq,'cDAQ1Mod1','ai1','Accelerometer');
	sys.ch2 = addinput(sys.dq,'cDAQ1Mod1','ai2','Accelerometer');
	sys.ch3 = addinput(sys.dq,'cDAQ1Mod1','ai3','Accelerometer');
	sys.ch4 = addinput(sys.dq,'cDAQ1Mod2','ai0','Accelerometer');
	sys.ch5 = addinput(sys.dq,'cDAQ1Mod2','ai1','Accelerometer');
	sys.ch6 = addinput(sys.dq,'cDAQ1Mod2','ai2','Accelerometer');
	sys.ch7 = addinput(sys.dq,'cDAQ1Mod2','ai3','Accelerometer');
	sys.ch8 = addinput(sys.dq,'cDAQ1Mod3','ai0','Accelerometer');
	sys.ch9 = addinput(sys.dq,'cDAQ1Mod3','ai1','Accelerometer');
	sys.ch10 = addinput(sys.dq,'cDAQ1Mod3','ai2','Accelerometer');
	sys.ch11 = addinput(sys.dq,'cDAQ1Mod3','ai3','Accelerometer');
	sys.ch12 = addinput(sys.dq,'cDAQ1Mod4','ai0','Accelerometer');
	sys.ch13 = addinput(sys.dq,'cDAQ1Mod4','ai1','Accelerometer');
	sys.ch14 = addinput(sys.dq,'cDAQ1Mod4','ai2','Accelerometer');
	sys.ch15 = addinput(sys.dq,'cDAQ1Mod4','ai3','Accelerometer');

	% Accelerometer and hammer specifications

	sys.ch0.Range = [0,1];
	sys.ch1.Sensitivity = 0.09735;
	sys.ch2.Sensitivity = 0.09360;
	sys.ch3.Sensitivity = 0.09786;
	sys.ch4.Sensitivity = 0.09635;
	sys.ch5.Sensitivity = 0.09859;
	sys.ch6.Sensitivity = 0.09841;
	sys.ch7.Sensitivity = 0.09813;
	sys.ch8.Sensitivity = 0.09508;
	sys.ch9.Sensitivity = 0.09566;
	sys.ch10.Sensitivity = 0.09794;
	sys.ch11.Sensitivity = 0.09638;
	sys.ch12.Sensitivity = 0.09405;
	sys.ch13.Sensitivity = 0.09615;
	sys.ch14.Sensitivity = 0.10309;
	sys.ch15.Sensitivity = 0.10287;

	sys.ch1.ExcitationCurrent = 0.002;
	sys.ch2.ExcitationCurrent = 0.002;
	sys.ch3.ExcitationCurrent = 0.002;
	sys.ch4.ExcitationCurrent = 0.002;
	sys.ch5.ExcitationCurrent = 0.002;
	sys.ch6.ExcitationCurrent = 0.002;
	sys.ch7.ExcitationCurrent = 0.002;
	sys.ch8.ExcitationCurrent = 0.002;
	sys.ch9.ExcitationCurrent = 0.002;
	sys.ch10.ExcitationCurrent = 0.002;
	sys.ch11.ExcitationCurrent = 0.002;
	sys.ch12.ExcitationCurrent = 0.002;
	sys.ch13.ExcitationCurrent = 0.002;
	sys.ch14.ExcitationCurrent = 0.002;
	sys.ch15.ExcitationCurrent = 0.002;

	sys.ch1.ExcitationSource = 'Internal';
	sys.ch2.ExcitationSource = 'Internal';
	sys.ch3.ExcitationSource = 'Internal';
	sys.ch4.ExcitationSource = 'Internal';
	sys.ch5.ExcitationSource = 'Internal';
	sys.ch6.ExcitationSource = 'Internal';
	sys.ch7.ExcitationSource = 'Internal';
	sys.ch8.ExcitationSource = 'Internal';
	sys.ch9.ExcitationSource = 'Internal';
	sys.ch10.ExcitationSource = 'Internal';
	sys.ch11.ExcitationSource = 'Internal';
	sys.ch12.ExcitationSource = 'Internal';
	sys.ch13.ExcitationSource = 'Internal';
	sys.ch14.ExcitationSource = 'Internal';
	sys.ch15.ExcitationSource = 'Internal';

	sys.ch0.Coupling = 'AC';
	sys.ch1.Coupling = 'AC';
	sys.ch2.Coupling = 'AC';
	sys.ch3.Coupling = 'AC';
	sys.ch4.Coupling = 'AC';
	sys.ch5.Coupling = 'AC';
	sys.ch6.Coupling = 'AC';
	sys.ch7.Coupling = 'AC';
	sys.ch8.Coupling = 'AC';
	sys.ch9.Coupling = 'AC';
	sys.ch10.Coupling = 'AC';
	sys.ch11.Coupling = 'AC';
	sys.ch12.Coupling = 'AC';
	sys.ch13.Coupling = 'AC';
	sys.ch14.Coupling = 'AC';
	sys.ch15.Coupling = 'AC';

	sys.ch0.TerminalConfig = 'PseudoDifferential';
	sys.ch1.TerminalConfig = 'PseudoDifferential';
	sys.ch2.TerminalConfig = 'PseudoDifferential';
	sys.ch3.TerminalConfig = 'PseudoDifferential';
	sys.ch4.TerminalConfig = 'PseudoDifferential';
	sys.ch5.TerminalConfig = 'PseudoDifferential';
	sys.ch6.TerminalConfig = 'PseudoDifferential';
	sys.ch7.TerminalConfig = 'PseudoDifferential';
	sys.ch8.TerminalConfig = 'PseudoDifferential';
	sys.ch9.TerminalConfig = 'PseudoDifferential';
	sys.ch10.TerminalConfig = 'PseudoDifferential';
	sys.ch11.TerminalConfig = 'PseudoDifferential';
	sys.ch12.TerminalConfig = 'PseudoDifferential';
	sys.ch13.TerminalConfig = 'PseudoDifferential';
	sys.ch14.TerminalConfig = 'PseudoDifferential';
	sys.ch15.TerminalConfig = 'PseudoDifferential';
end

