%%  Returns data and log file names used by various programs
%%  The paths in file names are relative to the current (code) directory 
%%  All parameters are taken from global structure 'session'

%%  Parameter:
%%	ffid - FFID for the requested trial. 
%%		If this parameter is given, files for this specific ffid are returned.
%%		If  no data file exists or it is not in any visible logs,
%%		a message is printed and logf=[] is returned.
%%		If this parameter is not given, 
%%		file names from 'session' are used without checking 
%%		(this is used for creating new log and data files)
%%  Returns:
%%      logf - name of log file
%%      dataf - name of data file saved by Extract_AC_signal.m
%%      patternf - name of pattern file

function [ logf, dataf, patternf ] = file_names( ffid )

global session

	logf = [];
	dataf = [];
	patternf = [];

	if nargin < 1		% use default name from 'session'
	
		ffid = session.trial_no;
		pattern = session.pattern;
	end

	warning off

	d = session.dir_project;

	mkdir(d);		% create directory in case it does not exist

	% form and create directory for data file

	d = [ d '/accel/' ];	

	mkdir(d);

	dataf = sprintf('%s/Trial_%03d_output.txt',d, ffid );

	% if asking for a specific ffid, check whether it exists and find the right log

	if nargin >= 1 
		if ~exist(dataf)			
			disp(sprintf('Requested trial = %d does not exist',ffid))
			dataf = [];
			return
		end
	end

	% figure out the log file

	if nargin < 1		% use default name from 'session'
	
		if length(session.log_suffix) > 0

			logf = sprintf('%s/log_line%03d_%s_%s.txt',session.dir_project, session.line_no, session.location, session.log_suffix);
		else
			logf = sprintf('%s/log_line%03d_%s.txt', session.dir_project, session.line_no, session.location );
		end

		% replace spaces with '_' in file name

		logf(find(isspace(logf))) = '_';

	else		% if specific ffid requested, find the log for it

		logf = filename_log( session.dir_project, 0, ffid );

		if isempty(logf)
			disp(sprintf('No log file for requested trial = %d',ffid))
			return
		end

		[ ~, ~, ~, ~, pattern ] = params_ffid(logf,ffid);	% obtain pattern from log
	end

	%% if DAQ emulation is used, always take pattern #2 from it

	if exist('../daq_emulation') 
		patternf = '../daq_emulation/pattern_002.txt';

	else		% otherwise (normal operation), take pattern from log directory

		patternf = sprintf('../config/pattern_%03d.txt', pattern);
	end

	warning on
end

