%%  Returns file name of log file for a given  line number or ffid

%% Parameters:
%%	rootdir - directory in which the log files are located
%%      line_no - line number, If line_no < 1, returns teh fiorst log containing 'ffid'.
%%		If line_no >= 1, returns teh first log containing this line number
%%	ffid - (optional) ffid number. If this parameter is given,
%%		several logs are tried until the ffid is found

%% Returns:
%%      logf - name of log file. If no log file is found, [] is returned

function logf = filename_log( rootdir, line_no, ffid )

  if nargin < 2
	ffid = 0;
  end

  logf = [];		% default

  tag = 'log_line';

  ntag = length(tag);

  tag = [ tag '.txt' ];

  % use 'ls -1' shell command

  wd = pwd();
  cd(rootdir);

  fn = ls('log*.txt');

  % find the first matching log file name
  % excluding names containing 'trigger'

  for i=1:size(fn,1)
		
    str = fn(i,:);

    while true 

	[ fn1, str ] = strtok(str);

	if length(fn1) < 1
		break
	end

	fn2 = fn1((ntag+1):end);

	% extract line number from file name

	digits = isstrprop(fn1((ntag+1):end),'digit');

	k = 0;

	for j=1:length(digits) 
		if digits(j)
			k = k+1;
		else
			break
		end
	end

	if k < 1		% no digits in file name, skip it
		continue
	end

	if line_no > 0 && str2num(fn2(1:k)) ~= line_no		% wrong line number, skip it
		continue
	end

	if strncmp(fn1,tag,ntag)		% log for this line

		if strfind(fn1,'trigger')	% this is not the right log
			continue
		end

		% if line_no was not given, check whether this log contains the needed ffid

		A = load(fn1,'-ascii');

		if line_no < 1 && isempty(find(A(:,2)==ffid))	% the log does not contain this ffid 
			continue
		end

		logf = [ rootdir, fn1 ];

		% return to the original directiory

		cd(wd);

		return
	end	

    end % while

  end	% for

  % return to the original directiory

  cd(wd);

end

