% Extracts parameter header from one line of log file
%
% Parameters:
%	s - string of commentary from log file (after stripping the '#')
% Returns:
%	ind - index of the field:
%		0 - this field is unknown;
%		1 - this field is Line
%		2 - this field is BaseSTN
%		3 - this field is BaseX
%		4 - this field is Station spacing
%		5 - this field is Line spacing
%		6 - this field is srcOFFSET (Source offset)
%		7 - this field is srcSKID (Source skid)
%		8 - this field is Receiver shift
%		9 - this field is Source shift
%		10 - this field is Pattern
%		11 - this field is Sources or Source
%	parstr - string value of the field if par > 0

function [ ind, parstr ] = params_header(s)

	parstr = "";

	n = find(s == ':' | s == '=' );

	if isempty(n)		% not a header
		ind = 0;
		return;
	end

	tok = strtrim(s(1:(n-1)));	% first token
	s = strtrim(s((n+1):end));	% second token

	if strcmpi(tok,'line')
		ind = 1;
	elseif strcmpi(tok,'basestn')
		ind = 2;
	elseif strcmpi(tok,'basex')
		ind = 3;
	elseif strcmpi(tok,'spacing') || strcmpi(tok,'spacingSTN')
		ind = 4;
	elseif strcmpi(tok,'spacingLIN') || strcmpi(tok,'spacingLINE')
		ind = 5;
	elseif strcmpi(tok,'srcOFFSET')
		ind = 6;
	elseif strcmpi(tok,'srcSKID')
		ind = 7;
	elseif strcmpi(tok,'recstnSHIFT')
		ind = 8;
	elseif strcmpi(tok,'srcstnSHIFT')
		ind = 9;
	elseif strcmpi(tok,'pattern')
		ind = 10;
	elseif strcmpi(tok,'sources') || strcmpi(tok,'source')
		ind = 11;
	else
		ind = 0;
	end

	if ind > 0
		parstr = strtok(s);	% output first token in the value 
	end
end

