% An example how to run the data acquisition and subsequent analysis
% =============================================================================

% 1) Set coordinates of all sensors in a file named as ../DATA/pattern_001.txt 
%
% 2) In the beginning of program Extract_AC_Signal.m, set variables describing 
% the upcoming hammer strike

% 3) Execute data acquisition program:

Extract_AC_Signal

%	The program will produce outputs:
%	---------------------------------------------------
%	Report trial number on the screen, 
%	Add parameters of this trial in a line at the end of ../DATA/TrialLog.txt
%	Create output data (archive) file ../DATA/Trial_<trial_no>_output.txt
%	Make a rough pick of the time of the hammer strike, and extract a time window around it
%	Execute first_display() to display the waveforms, velocity range, and the selection of strike time 
%	Create data file ../DATA/Trial_<trial_no>_reduced.mat containing data and other parameters.
%		This file will be used for all subsequent processing.

% ======================================================================================================
% The following steps contain data analysis.
% They can (and maybe should) be repeated multiple times, and for various previous trials.
% ======================================================================================================

% 4) Execute first_display.m in several (optional) ways:
%    For instance, to process trial number 13:

first_display(13);		% display and extract reduced data from trial 13
first_display(13,497.5);	% set strike time equal 497.5 ms
first_display(13,[],[480,550]);  % pick the strike time automatically and change the extraction window 

%	In each of these calls, the corresponding ../DATA/Trial_<trial_no>_output.txt is loaded,
%	a display is created, and file ../DATA/Trial_<trial_no>_reduced.mat is output

		% NOTE 1: setting a wildly incorrect strike time or window may result
		% in the extracted data window being empty.
		% I have added error messages pointing this situation out.

		% NOTE 2: neither the strike time nor this window are important for subsequent
		% analysis, so you can simply always use the first of the above calls. 


% 5) Execute accel_spectra(). For instance, for trial number 13:

accel_spectra(13);		

%	This program loads file ../DATA/Trial_<trial_no>_reduced.mat,
%	shows plots of spectra, but makes no outputs

% 6) Execute accel_dispersion.m. For instance, for trial number 13:

accel_dispersion(13);		

%	This program also loads file ../DATA/Trial_<trial_no>_reduced.mat,
%	shows a plot of semblance on a velocity/frequency plane, and measures ppoints of highest semblance.
%	It also outputs the semblance results into file ../DATA/Trial_<trial_no>_dispersion.mat
%	(for use in subsequent inversion)

