%% If parameter str is given, writes out in the survey.observer's log file the time stamp, 
%% followed by string 'str', followed by "\n".

%% If str is not given, writes out one line with parameters of the most recent data file.

function write_log(str)

  global session sett survey
  
  % obtain common settings and survey parameters as in seismograph programs

  sett = get_settings();
  [ projname, survey ] = get_survey();

  status.trigger = 1;		% make a trigger number up; it is not used

  if exist(session.log_filename)                % log exists, open for appending
      fid = fopen(session.log_filename,"at");
  else                                    	% open new

	% reset the source counter for the new line

	session.src_no = 1;

        fid = fopen(session.log_filename,"wt");

      	% write out log header (the same as for seismograph with additional fields)

      	fprintf(fid, "%% Project    : %s\n", projname);
      	fprintf(fid, "%% Trial      : %s\n", survey.name);
      	fprintf(fid, "%% Lane       : %s\n", survey.location);
     	fprintf(fid, "%% Line       : %d\n", survey.curr_line);
      	fprintf(fid, "%% Vintage    : %d  \t%% using the number of load cycles as vintage\n", session.dq_load_cycles);
      	fprintf(fid, "%% LoadCycles : %d\n\n", session.dq_load_cycles);

      	fprintf(fid, "%% Observer   : %s\n", survey.observer);
      	fprintf(fid, "%% Start time : %s\n\n", datestr(now(),'dd-mmm-yyyy HH:MM'));

      	fprintf(fid, "%% Sources    : %s\n", survey.obs_sources);

      	fprintf(fid, "%% Instrument : %s, %d chan\n", sett.instrument, sett.num_channels);
      	fprintf(fid, "%% Receivers  : %s\n", survey.obs_geophones);
      	fprintf(fid, "%% Spread     : %s\n", survey.obs_spread);
	fprintf(fid, "%% BaseSTN    : %d  \t%% station of chan=1 in first roll\n", survey.base_station);
	fprintf(fid, "%% BaseX      : %1.3f \t%% coordinate of BaseSTN\n", survey.base_x);
	fprintf(fid, "%% SpacingSTN : %1.3f \t%% nominal spacing between receiver stations\n", survey.obs_rec_spacing);

	% write a line indicating headings of columns

	fprintf(fid, "\n");

	write_log_FFID_header(fid);

  end

  % if no argument given, list parameters of current FFID in one log line
  
  if nargin < 1       
    
    spread = [ 1, sett.num_channels ];	% always fixed spread for accelerometers

    datenow = datestr(now(),'HH:MM:SS');

    % write pattern header if first time or the pattern or source position have changed

    write_log_patt(fid);
	
    if survey.threeD
    	fprintf(fid, "  %7d    %05d %9d %9d %9d %9d %4d   %s\n", curr_source(), survey.curr_ffid, ...
			survey.curr_srcline, survey.curr_srcstn,  ...
			spread(1), spread(2), status.trigger, datenow);
    else
    	fprintf(fid, "  %7d    %9d %9d %9d %9d %4d   %s\n", curr_source(), survey.curr_ffid, ...
			survey.curr_srcstn,  ...
			spread(1), spread(2), status.trigger, datenow);
    end

  else			% otherwise output observer's message

    fputs(fid,[ "%%% " datestr(now(),"HH:MM") " % " str "\n" ]);
  end

  fclose(fid);
  
end

